==> quartet_capture-2.2.9.tar.gz: quartet_capture-2.2.9/quartet_capture/haiku.py <==
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2018 SerialLab Corp.  All rights reserved.
adjectives = [
    'aged', 'ancient', 'autumn', 'billowing', 'bitter', 'black', 'blue',
    'bold',
    'broad', 'broken', 'calm', 'cold', 'cool', 'crimson', 'curly', 'deft',
    'dark', 'dawn', 'dim', 'divine', 'dry', 'empty', 'falling', 'fancy',
    'flat', 'floral', 'fragrant', 'frosty', 'grey', 'green', 'hidden',
    'holy',
    'icy', 'jolly', 'late', 'lingering', 'left', 'lively', 'legal', 'lucky',
    'misty', 'morning', 'muddy', 'mute', 'nameless', 'noisy', 'odd', 'olive',
    'orange', 'patient', 'plain', 'polished', 'proud', 'punctual', 'quiet',
    'rapid',
    'raspy', 'red', 'restless', 'rough', 'round', 'royal', 'shiny', 'shrill',
    'shy', 'silent', 'small', 'snowy', 'soft', 'solitary', 'sparkling',
    'spring',
    'square', 'steep', 'still', 'summer', 'super', 'shining', 'tall',
    'thundering',
    'tenacious', 'twilight', 'wandering', 'weathered', 'white', 'wild', 'winter',
    'wispy',
    'withered', 'yellow', 'yonder'
]

nouns = [
    'art', 'band', 'bar', 'base', 'bird', 'block', 'boat', 'bonus',
    'bread', 'breeze', 'brook', 'car', 'butterfly', 'cake', 'cell', 'calendar',
    'cloud', 'credit', 'darkness', 'dawn', 'dew', 'disk', 'dream', 'dust',
    'feather', 'field', 'fire', 'firefly', 'factory', 'fog', 'forest', 'frog',
    'frost', 'glade', 'glitter', 'grass', 'hall', 'hat', 'haze', 'heart',
    'hill', 'king', 'lab', 'lake', 'leaf', 'limit', 'math', 'meadow',
    'mode', 'moon', 'morning', 'mountain', 'mouse', 'mud', 'night', 'paper',
    'pine', 'poetry', 'pond', 'quilt', 'rain', 'recipe', 'resonance', 'rice',
    'river', 'sail', 'scene', 'sea', 'shadow', 'shape', 'silence', 'sky',
    'smoke', 'snow', 'snowflake', 'sound', 'star', 'sun', 'sun', 'sunset',
    'surf', 'term', 'thunder', 'tea', 'tree', 'truth', 'union', 'unit',
    'violet', 'voice', 'water', 'waterfall', 'wave', 'wildflower', 'wind',
    'water'
]

==> quartet_capture-2.2.10.tar.gz: quartet_capture-2.2.10/quartet_capture/haiku.py <==
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2018 SerialLab Corp.  All rights reserved.
adjectives = [
    'advancing', 'ancient', 'autumn', 'billowing', 'bitter', 'black', 'blue',
    'bold',
    'broad', 'broken', 'calm', 'cold', 'cool', 'crimson', 'curly', 'deft',
    'dark', 'dawn', 'dim', 'divine', 'dry', 'empty', 'falling', 'fancy',
    'flat', 'floral', 'fragrant', 'frosty', 'grey', 'green', 'hidden',
    'holy',
    'icy', 'jolly', 'late', 'lingering', 'left', 'lively', 'legal', 'lucky',
    'misty', 'morning', 'maroon', 'mute', 'nameless', 'noisy', 'open', 'olive',
    'orange', 'patient', 'plain', 'polished', 'proud', 'punctual', 'quiet',
    'rapid',
    'raspy', 'rapid', 'restless', 'raining', 'rectangular', 'royal', 'shining', 'shrill',
    'sole', 'silent', 'stone', 'snowy', 'soft', 'solitary', 'sparkling',
    'spring',
    'square', 'steep', 'still', 'summer', 'super', 'shining', 'tall',
    'thundering',
    'tenacious', 'twilight', 'wandering', 'weathered', 'white', 'wild', 'winter',
    'wispy',
    'withered', 'yeadon'
]

nouns = [
    'art', 'band', 'bar', 'base', 'brick', 'block', 'boat', 'bonus',
    'bread', 'breeze', 'brook', 'car', 'butterfly', 'cone', 'cell', 'calendar',
    'cloud', 'credit', 'darkness', 'dawn', 'dam', 'disk', 'dream', 'dust',
    'feather', 'field', 'fire', 'firefly', 'factory', 'fog', 'forest', 'frog',
    'frost', 'glade', 'glitter', 'grass', 'hall', 'hat', 'haze', 'home',
    'hill', 'king', 'lab', 'lake', 'leaf', 'limit', 'math', 'meadow',
    'mode', 'moon', 'morning', 'mountain', 'mist', 'mud', 'night', 'paper',
    'pine', 'poetry', 'pond', 'quilt', 'rain', 'recipe', 'resonance', 'rice',
    'river', 'sail', 'scene', 'sea', 'shadow', 'shape', 'silence', 'sky',
    'smoke', 'snow', 'snowflake', 'sound', 'star', 'sun', 'sun', 'sunset',
    'surf', 'term', 'thunder', 'tea', 'tree', 'truth', 'union', 'unit',
    'violet', 'voice', 'water', 'waterfall', 'wave', 'wildflower', 'wind',
    'water'
]
